# Ruby Tricks, Idiomatic Ruby, Refactorings and Best Practices

> Do you know why experienced Ruby programmers tend to reach for basic collections
> and hashes while programmers from other languages go for more specialized classes?
> Do you know the difference between strip, chop, and chomp, and why there are three
> such similar methods when apparently one might suffice? (Not to mention lstrip and
> rstrip!) Do you know the downsides of dynamic typing? Do you know why the differences
> between strings and symbols get so blurry, even to experienced Ruby developers?
> How about metaprogramming? What the heck is an eigenclass? How about
> protected methods? Do you know what they’re really about? Really? Are you sure?
[Eloquent Ruby](http://www.amazon.com/Eloquent-Ruby-Addison-Wesley-Professional/dp/0321584104)

> Absolutely the best way to learn to write idiomatic Ruby code is to read idiomatic Ruby code. [Eloquent Ruby](http://www.amazon.com/Eloquent-Ruby-Addison-Wesley-Professional/dp/0321584104)

This repository aims to help everyone to write a more idiomatic, clean and tricky ruby code and also try to join a bunch of good refactoring techniques. You can add your own technique or paste it from some website(do not forget the source, of course). All the tricks are in the /tricks folder.

For the sake of reading, you should paste in the markdown format and at the end, paste where the technique come from, if it's not yours.

## [Tricks](tricks.md)

In this part we can check some obscure or awesome features from the and the standard ruby library which normally we forget.

## [Idiomatic Ruby](idiomatic_ruby.md)

You can write a Ruby code, but it can look like a Java code for example. Here you can find some tips to write a more natural and take advantage of Ruby.

## [Refactorings](refactorings.md)

Small (and big) improvements you can apply to your code and improve it's readability and maintenance. Change the internal structure of the code without changing it's behaviour.

## [Best Practices](best_practices.md)

If you keep your house cleaned constantly you'll never need to waste a weekend cleaning it. The same applys to your code, be disciplined and keep your code looking good with those tips.

## Contributors

A big thanks to the following [persons](https://github.com/franzejr/best-ruby/graphs/contributors)

## Contributing

1. [Fork it](https://github.com/franzejr/best-ruby)
2. Create your refactoring technique branch: `git checkout -b my-technique`
3. Add your technique to the collection of `.md` files in the correct folder (tricks, refactorings, idiomatic_ruby or best_practices) folder
4. Commit your changes: `git commit -am 'Add my technique'`
5. Push to the branch: `git push origin mytechnique`
6. Create a new Pull Request and explain your technique in the markdown file
